==> at_theme_flutter-1.0.2.tar.gz: lib/services/theme_service.dart <==
import 'dart:convert';

import 'package:at_client_mobile/at_client_mobile.dart';
import 'package:at_commons/at_commons.dart';
import 'package:at_theme_flutter/at_theme_flutter.dart';
import 'package:at_theme_flutter/utils/constants.dart';

class ThemeService {
  ThemeService._();
  static final ThemeService _instance = ThemeService._();
  factory ThemeService() => _instance;

  String? rootDomain;
  int? rootPort;
  String? currentAtsign;

  initThemeService(String rootDomainFromApp, int rootPortFromApp) {
    rootDomain = rootDomainFromApp;
    rootPort = rootPortFromApp;
    currentAtsign = AtClientManager.getInstance().atClient.getCurrentAtSign();
  }

  Future<bool> updateThemeData(AppTheme themeData) async {
    AtKey atKey = getAtkey();
    try {
      var result = await AtClientManager.getInstance()
          .atClient
          .put(atKey, themeData.encoded());
      return result;
    } catch (e) {
      print('error in updating theme data: ${e.toString()}');
      return false;
    }
  }

  Future<AppTheme?> getThemeData() async {
    try {
      AtKey atKey = getAtkey();
      var atValue = await AtClientManager.getInstance().atClient.get(atKey);

      if (atValue.value == null && atValue.value == 'null') {
        return null;
      }

      AppTheme? themeData = AppTheme.decode(jsonDecode(atValue.value));
      return themeData;
    } catch (e) {
      print('error in getThemeData : ${e.toString()}');
    }
    return null;
  }

  AtKey getAtkey() {
    Metadata metaData = Metadata();
    AtKey atKey = AtKey()
      ..key = MixedConstants.theme_key
      ..metadata = metaData
      ..metadata!.ttr = -1
      ..metadata!.ccd = true;

    return atKey;
  }
}

==> at_theme_flutter-1.0.3.tar.gz: lib/services/theme_service.dart <==
import 'dart:convert';

import 'package:at_client_mobile/at_client_mobile.dart';
import 'package:at_theme_flutter/at_theme_flutter.dart';
import 'package:at_theme_flutter/utils/constants.dart';
import 'package:at_utils/at_utils.dart';

class ThemeService {
  ThemeService._();
  static final ThemeService _instance = ThemeService._();
  factory ThemeService() => _instance;

  final _logger = AtSignLogger('ThemeService');

  String? rootDomain;
  int? rootPort;
  String? currentAtsign;

  initThemeService(String rootDomainFromApp, int rootPortFromApp) {
    rootDomain = rootDomainFromApp;
    rootPort = rootPortFromApp;
    currentAtsign = AtClientManager.getInstance().atClient.getCurrentAtSign();
  }

  Future<bool> updateThemeData(AppTheme themeData) async {
    AtKey atKey = getAtkey();
    try {
      var result = await AtClientManager.getInstance()
          .atClient
          .put(atKey, themeData.encoded());
      return result;
    } catch (e) {
      _logger.severe('error in updating theme data: ${e.toString()}');
      return false;
    }
  }

  Future<AppTheme?> getThemeData() async {
    try {
      AtKey atKey = getAtkey();
      var atValue = await AtClientManager.getInstance().atClient.get(atKey);

      if (atValue.value == null && atValue.value == 'null') {
        return null;
      }

      AppTheme? themeData = AppTheme.decode(jsonDecode(atValue.value));
      return themeData;
    } catch (e) {
      _logger.severe('error in getThemeData : ${e.toString()}');
    }
    return null;
  }

  AtKey getAtkey() {
    Metadata metaData = Metadata();
    AtKey atKey = AtKey()
      ..key = MixedConstants.theme_key
      ..metadata = metaData
      ..metadata!.ttr = -1
      ..metadata!.ccd = true;

    return atKey;
  }
}
